Class: Legion::Extensions::ServiceNow::Skills::ProblemManagement
- Inherits:
-
LLM::Skills::Base
- Object
- LLM::Skills::Base
- Legion::Extensions::ServiceNow::Skills::ProblemManagement
- Defined in:
- lib/legion/extensions/service_now/skills/problem_management.rb
Instance Method Summary collapse
-
#complete(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument.
-
#document_workaround(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument.
-
#identify_problem(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument.
-
#implement_fix(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument.
-
#investigate_root_cause(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument.
Instance Method Details
#complete(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument
50 51 52 53 54 55 |
# File 'lib/legion/extensions/service_now/skills/problem_management.rb', line 50 def complete(context: {}) # rubocop:disable Lint/UnusedMethodArgument Legion::LLM::Skills::StepResult.new( inject: 'Problem management workflow complete.', metadata: { step: 'complete' } ) end |
#document_workaround(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument
35 36 37 38 39 40 |
# File 'lib/legion/extensions/service_now/skills/problem_management.rb', line 35 def document_workaround(context: {}) # rubocop:disable Lint/UnusedMethodArgument Legion::LLM::Skills::StepResult.new( inject: 'Documenting workaround and marking as known error if applicable.', metadata: { step: 'document_workaround' } ) end |
#identify_problem(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument
20 21 22 23 24 25 |
# File 'lib/legion/extensions/service_now/skills/problem_management.rb', line 20 def identify_problem(context: {}) # rubocop:disable Lint/UnusedMethodArgument Legion::LLM::Skills::StepResult.new( inject: 'Identifying the problem record and linking related incidents.', metadata: { step: 'identify_problem' } ) end |
#implement_fix(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument
42 43 44 45 46 47 48 |
# File 'lib/legion/extensions/service_now/skills/problem_management.rb', line 42 def implement_fix(context: {}) # rubocop:disable Lint/UnusedMethodArgument Legion::LLM::Skills::StepResult.new( inject: 'Implementing permanent fix and closing the problem record.', metadata: { step: 'implement_fix' }, gate: :confirm ) end |
#investigate_root_cause(context: {}) ⇒ Object
rubocop:disable Lint/UnusedMethodArgument
27 28 29 30 31 32 33 |
# File 'lib/legion/extensions/service_now/skills/problem_management.rb', line 27 def investigate_root_cause(context: {}) # rubocop:disable Lint/UnusedMethodArgument Legion::LLM::Skills::StepResult.new( inject: 'Investigating root cause using incident history and audit trail.', metadata: { step: 'investigate_root_cause' }, gate: :confirm ) end |